@@ -112,15 +112,19 @@ class Config:
 
     # General purpose scipion tmp folder
     SCIPION_TMP = _get('SCIPION_TMP', _join(SCIPION_USER_DATA, 'tmp'))
-    # LOGS PATHS
-    # Path for Scipion logs
+    # LOGGING variables
+    # Path for Scipion logs folder: used by GUI
     SCIPION_LOGS = _get('SCIPION_LOGS', _join(SCIPION_USER_DATA, 'logs'))
+    # Optional: custom logging configuration file
+    SCIPION_LOG_CONFIG = _get('SCIPION_LOG_CONFIG', None)
+    # Get general log file path (for the GUI)
+    SCIPION_LOG = _join(SCIPION_LOGS, 'scipion.log')
+    # Default logging level: String among CRITICAL, ERROR, WARNING, INFO, DEBUG, NOTSET
+    SCIPION_LOG_LEVEL = _get(SCIPION_LOG_LEVEL, 'INFO')
+
     # Scratch path
     SCIPION_SCRATCH = _get(SCIPION_SCRATCH, None)
 
-    # Get general log file path
-    SCIPION_LOG = _join(SCIPION_LOGS, 'scipion.log')
-
     # Where the output of the tests will be stored
     SCIPION_TESTS_OUTPUT = _get('SCIPION_TESTS_OUTPUT', _join(SCIPION_USER_DATA, 'Tests'))
 
@@ -164,6 +168,14 @@ class Config:
     # Cancel shutil fast copy. In GPFS, shutil.copy does fail when trying a fastcopy and does not fallback on the slow copy.
     SCIPION_CANCEL_FASTCOPY = _get('SCIPION_CANCEL_FASTCOPY', None)
 
+    # Priority package list: This variable is used in the view protocols in
+    # order to load first the plugins that contains the main protocols.conf
+    # sections, so other plugins can define only their sections avoiding
+    # duplicating all the sections in all plugins
+    SCIPION_PRIORITY_PACKAGE_LIST = _get('SCIPION_PRIORITY_PACKAGE_LIST', None)
+
+    # Time in seconds to check the protocols steps. The default value is 3 seconds
+    SCIPION_STEPS_CHECK_SEC = int(_get('SCIPION_STEPS_CHECK_SEC', 3))
 
     try:
         VIEWERS = ast.literal_eval(_get('VIEWERS', "{}"))
@@ -263,9 +275,20 @@ class Config:
 
     @staticmethod
     def toggleDebug():
-        newValue = not Config.debugOn()
-        os.environ[SCIPION_DEBUG] = str(newValue)
-        os.environ[SCIPION_DEBUG_NOCLEAN] = str(newValue)
+        debugOn = not Config.debugOn()
+        os.environ[SCIPION_DEBUG] = str(debugOn)
+        os.environ[SCIPION_DEBUG_NOCLEAN] = str(debugOn)
+        os.environ[SCIPION_LOG_LEVEL] = "INFO" if not debugOn else "DEBUG"
+
+    @staticmethod
+    def debugSQLOn():
+        from .utils import envVarOn
+        return bool(envVarOn(SCIPION_DEBUG_SQLITE))
+
+    @staticmethod
+    def toggleDebugSQL():
+        newValue = not Config.debugSQLOn()
+        os.environ[SCIPION_DEBUG_SQLITE] = str(newValue)
 
     @classmethod
     def refreshInThreads(cls):
@@ -280,6 +303,17 @@ class Config:
     def getWizardMaskColor(cls):
         return json.loads(cls.WIZARD_MASK_COLOR)
 
+    @classmethod
+    def getPriorityPackageList(cls):
+        if cls.SCIPION_PRIORITY_PACKAGE_LIST is not None:
+            return cls.SCIPION_PRIORITY_PACKAGE_LIST.split(" ")
+        else:
+            return []
+
+    @classmethod
+    def getStepsCheckSeconds(cls):
+        return cls.SCIPION_STEPS_CHECK_SEC
+
 
 # Add bindings folder to sys.path
 sys.path.append(Config.getBindingsFolder())
