@@ -89,6 +89,7 @@ class Canvas(tk.Canvas, Scrollable):
 
         self._runsFont = getDefaultFont().copy()
         self._zoomFactor = DEFAULT_ZOOM
+        self.nodeList = None
 
         if tooltipCallback:
             self.bind('<Motion>', self.onMotion)
@@ -364,7 +365,7 @@ class Canvas(tk.Canvas, Scrollable):
     def zoomerM(self, event):
         self.__zoom(event, 0.9)
 
-    def drawGraph(self, graph, layout=None, drawNode=None):
+    def drawGraph(self, graph, layout=None, drawNode=None, nodeList=None):
         """ Draw a graph in the canvas.
         nodes in the graph should have x and y.
         If layout is not None, it will be used to 
@@ -377,6 +378,7 @@ class Canvas(tk.Canvas, Scrollable):
         scale = self._zoomFactor / DEFAULT_ZOOM
         self._zoomFactor = DEFAULT_ZOOM
         self._runsFont['size'] = DEFAULT_FONT_SIZE
+        self.nodeList = nodeList
 
         if drawNode is None:
             self.drawNode = self._drawNode
@@ -397,7 +399,7 @@ class Canvas(tk.Canvas, Scrollable):
 
         layout.draw(graph)
         # Update node positions
-        self._updatePositions(graph.getRoot(), {})
+        self._updatePositions(graph.getRoot(), {}, createEdges=False)
         self.updateScrollRegion()
 
     def _drawNode(self, canvas, node):
@@ -418,11 +420,45 @@ class Canvas(tk.Canvas, Scrollable):
 
             if getattr(node, 'expanded', True):
                 for child in node.getChilds():
-                    self._drawNodes(child, visitedDict)
-                    self.createEdge(item, child.item)
+                    if self.nodeList is None:
+                        self._drawNodes(child, visitedDict)
+                    elif self.nodeList.getNode(child.run.getObjId()).isVisible():
+                        self._drawNodes(child, visitedDict)
+                    else:
+                        self._setupParentProperties(node, visitedDict)
             else:
                 self._setupParentProperties(node, visitedDict)
 
+    def _connectParents(self, item):
+        """
+        Establishes a connection between the visible parents of node's children
+        with node
+        """
+        visibleParents = self._visibleParents(item, [])
+        for visibleParent in visibleParents:
+            if visibleParent != item:
+                dest = self.items[item.item.id]
+                source = self.items[visibleParent.item.id]
+                visibleParentNode = self.nodeList.getNode(visibleParent.run.getObjId())
+                itemNode = self.nodeList.getNode(item.run.getObjId())
+
+                if visibleParent not in item.getParents() and visibleParentNode.isExpanded():
+                    self.createEdge(source, dest)
+                if not itemNode.isExpanded():
+                    self.createEdge(source, dest)
+
+    def _visibleParents(self, node, parentlist):
+        """
+        Return a list with the visible parents of the node's children
+        """
+        for child in node.getChilds():
+            parents = child.getParents()
+            for parent in parents:
+                parentNode = self.nodeList.getNode(parent.run.getObjId())
+                if parentNode.isVisible() and parent != node and parent not in parentlist:
+                        parentlist.append(parent)
+        return parentlist
+
     def _setupParentProperties(self, node, visitedDict):
         """ This methods is used for collapsed nodes, in which 
         the properties (width, height, x and y) is propagated
@@ -436,7 +472,7 @@ class Canvas(tk.Canvas, Scrollable):
                 child.y = node.y
                 self._setupParentProperties(child, visitedDict)
 
-    def _updatePositions(self, node, visitedDict={}):
+    def _updatePositions(self, node, visitedDict=None, createEdges=True):
         """ Update position of nodes and create the edges. """
         nodeName = node.getName()
 
@@ -447,7 +483,17 @@ class Canvas(tk.Canvas, Scrollable):
 
             if getattr(node, 'expanded', True):
                 for child in node.getChilds():
-                    self._updatePositions(child, visitedDict)
+                    if self.nodeList is None:
+                        self.createEdge(item, child.item)
+                        self._updatePositions(child, visitedDict, createEdges)
+                    elif self.nodeList.getNode(child.run.getObjId()).isVisible():
+                        if createEdges:
+                            self.createEdge(item, child.item)
+                        self._updatePositions(child, visitedDict, createEdges)
+            else:
+                if createEdges:
+                    self._connectParents(node)
+                self._updatePositions(node, visitedDict, createEdges)
 
 
 def findClosestPoints(list1, list2):
@@ -593,13 +639,21 @@ class Item(object):
     def getSocketCoordsAt(self, verticalLocation, position=1, socketsCount=1):
         x1, y1, x2, y2 = self.getCorners()
         xc = (x2 + x1) / 2.0
+        yc = (y1 + y2) / 2.0
+
         socketsGroupSize = (socketsCount - 1) * self.socketSeparation
         socketsGroupStart = xc - (socketsGroupSize / 2)
         x = socketsGroupStart + (position - 1) * self.socketSeparation
         if verticalLocation == "top":
             y = y1
-        else:
+        elif verticalLocation == 'bottom':
             y = y2
+        elif verticalLocation == 'left':
+            y = yc
+            x = x1
+        else:
+            y = yc
+            x = x2
         return x, y
 
     def relocateSockets(self, verticalLocation, count):
