@@ -30,7 +30,8 @@ some code was taken from tkSimpleDialog
 """
 import tkinter as tk
 import traceback
-from tkinter.colorchooser import askcolor as _askColor
+# from tkinter.colorchooser import askcolor as _askColor
+from tkcolorpicker import askcolor as _askColor
 
 from pyworkflow.exceptions import PyworkflowException
 from pyworkflow.utils import Message, Icon
@@ -44,6 +45,7 @@ RESULT_NO = 1
 RESULT_CANCEL = 2
 RESULT_RUN_SINGLE = 3
 RESULT_RUN_ALL = 4
+RESULT_CLOSE = 5
 
 
 class Dialog(tk.Toplevel):
@@ -95,7 +97,8 @@ class Dialog(tk.Toplevel):
         self.icons = kwargs.get('icons',
                                 {RESULT_YES: Icon.BUTTON_SELECT,
                                  RESULT_NO: Icon.BUTTON_CLOSE,
-                                 RESULT_CANCEL: Icon.BUTTON_CANCEL})
+                                 RESULT_CANCEL: Icon.BUTTON_CANCEL,
+                                 RESULT_CLOSE: Icon.BUTTON_CLOSE})
 
         self.buttons = kwargs.get('buttons', [('OK', RESULT_YES),
                                               ('Cancel', RESULT_CANCEL)])
@@ -172,7 +175,7 @@ class Dialog(tk.Toplevel):
         It will set the resultValue associated with the button
         and close the Dialog"""
         self.result = resultValue
-        noCancel = self.result != RESULT_CANCEL
+        noCancel = self.result != RESULT_CANCEL and self.result != RESULT_CLOSE
 
         if noCancel and not self.validate():
             self.initial_focus.focus_set()  # put focus back
@@ -524,8 +527,8 @@ def askString(title, label, parent, entryWidth=20, defaultValue='', headerLabel=
     return d.value
 
 
-def askColor(defaultColor='black'):
-    (rgbcolor, hexcolor) = _askColor(defaultColor)
+def askColor(parent, defaultColor='black'):
+    (rgbcolor, hexcolor) = _askColor(defaultColor, parent=parent)
     return hexcolor
 
 
@@ -558,7 +561,10 @@ class ListDialog(Dialog):
         buttons = []
         if kwargs.get('allowSelect', True):
             buttons.append(('Select', RESULT_YES))
-        buttons.append(('Cancel', RESULT_CANCEL))
+        if kwargs.get('cancelButton', False):
+            buttons.append(('Close', RESULT_CLOSE))
+        else:
+            buttons.append(('Cancel', RESULT_CANCEL))
 
         Dialog.__init__(self, parent, title, buttons=buttons, **kwargs)
 
