@@ -227,7 +227,8 @@ class MenuConfig(object):
 class NodeConfig(pwobj.Scalar):
     """ Store Graph node information such as x, y. """
 
-    def __init__(self, nodeId=0, x=None, y=None, selected=False, expanded=True):
+    def __init__(self, nodeId=0, x=None, y=None, selected=False, expanded=True,
+                 visible=True):
         pwobj.Scalar.__init__(self)
         # Special node id 0 for project node
         self._values = {'id': nodeId,
@@ -235,6 +236,7 @@ class NodeConfig(pwobj.Scalar):
                         'y': pwobj.Integer(y).get(0),
                         'selected': selected,
                         'expanded': expanded,
+                        'visible': pwobj.Boolean(visible).get(0),
                         'labels': []}
 
     def _convertValue(self, value):
@@ -284,6 +286,14 @@ class NodeConfig(pwobj.Scalar):
     def isExpanded(self):
         return self._values['expanded']
 
+    def setVisible(self, visible):
+        self._values['visible'] = visible
+
+    def isVisible(self):
+        if self._values.get('visible') is None:
+            self._values['visible'] = True
+        return self._values['visible']
+
     def setLabels(self, labels):
         self._values['labels'] = labels
 
