@@ -34,11 +34,12 @@ import traceback
 from collections import OrderedDict
 
 import pyworkflow as pw
+from pyworkflow.constants import PROJECT_DBNAME, PROJECT_SETTINGS
 import pyworkflow.object as pwobj
 import pyworkflow.protocol as pwprot
 import pyworkflow.utils as pwutils
 from pyworkflow.mapper import SqliteMapper
-from pyworkflow.protocol.constants import (MODE_RESTART, MODE_CONTINUE,
+from pyworkflow.protocol.constants import (MODE_RESTART, MODE_RESUME,
                                            STATUS_INTERACTIVE, ACTIVE_STATUS,
                                            UNKNOWN_JOBID, INITIAL_SLEEP_TIME)
 from pyworkflow.protocol.protocol import ProtImportBase
@@ -47,12 +48,10 @@ from . import config
 
 
 OBJECT_PARENT_ID = pwobj.OBJECT_PARENT_ID
-PROJECT_DBNAME = 'project.sqlite'
 PROJECT_LOGS = 'Logs'
 PROJECT_RUNS = 'Runs'
 PROJECT_TMP = 'Tmp'
 PROJECT_UPLOAD = 'Uploads'
-PROJECT_SETTINGS = 'settings.sqlite'
 PROJECT_CONFIG = '.config'
 PROJECT_CREATION_TIME = 'CreationTime'
 
@@ -499,9 +498,6 @@ class Project(object):
                 self._storeProtocol(protocol)
                 self._updateProtocol(protocol)
                 self.mapper.commit()
-                print("The parameters configuration in the "
-                      "protocol \"%s\" has been modified \n" %
-                      protocol.getObjLabel())
 
     def stopWorkFlow(self, activeProtList):
         """
@@ -524,13 +520,14 @@ class Project(object):
         errorProtList = []
         if workflowProtocolList:
             for protocol, level in workflowProtocolList.values():
-                try:
-                    self.resetProtocol(protocol)
-                except Exception:
-                    errorProtList.append(protocol)
+                if protocol.getStatus() != pwprot.STATUS_SAVED:
+                    try:
+                        self.resetProtocol(protocol)
+                    except Exception:
+                        errorProtList.append(protocol)
         return errorProtList
 
-    def launchWorkflow(self, workflowProtocolList, mode=MODE_CONTINUE):
+    def launchWorkflow(self, workflowProtocolList, mode=MODE_RESUME):
         """
         This function can launch a workflow from a selected protocol in two
         modes depending on the 'mode' value (RESTART, CONTINUE)
@@ -977,6 +974,7 @@ class Project(object):
         newProt.setObjLabel(newProtLabel)
         newProt.copyDefinitionAttributes(protocol)
         newProt.copyAttributes(protocol, 'hostName', '_useQueue', '_queueParams')
+        newProt.runMode.set(MODE_RESTART)
 
         return newProt
 
