@@ -34,7 +34,7 @@ import pyworkflow as pw
 from pyworkflow.exceptions import ValidationException, PyworkflowException
 from pyworkflow.object import *
 import pyworkflow.utils as pwutils
-from pyworkflow.utils.log import ScipionLogger
+from pyworkflow.utils.log import LoggingConfigurator, getExtraLogInfo, STATUS, setDefaultLoggingContext
 from .executor import (StepExecutor, ThreadStepExecutor, MPIStepExecutor,
                        QueueStepExecutor)
 from .constants import *
@@ -42,6 +42,10 @@ from .params import Form
 
 SCHEDULE_LOG = 'schedule.log'
 
+import  logging
+# Get the root logger
+logger = logging.getLogger(__name__)
+
 
 class Step(Object):
     """ Basic execution unit.
@@ -321,10 +325,31 @@ class Protocol(Step):
 
     # Version where protocol appeared first time
     _lastUpdateVersion = pw.VERSION_1
-    _stepsCheckSecs = 3
+    _stepsCheckSecs = pw.Config.getStepsCheckSeconds()
     # Protocol develop status: PROD, BETA, NEW
     _devStatus = pw.PROD
 
+    """" Possible Outputs:
+    This is an optional but recommended attribute to fill.
+    It has to be an enum with names being the name of the output and value the class of the output:
+    
+        class MyOutput(enum.Enum):
+            outputMicrographs = SetOfMicrographs
+            outputMicrographDW = SetOfMicrographs
+    
+    When defining outputs you can, optionally, use this enum like:
+    self._defineOutputs(**{MyOutput.outputMicrographs.name, setOfMics})
+    It will help to keep output names consistently
+    
+    Alternative an inline dictionary will work:
+    _possibleOutputs = {"outputMicrographs" : SetOfMicrographs}
+    
+    For a more fine detailed/dynamic output based on parameters, you can overwrite the getter:
+    getPossibleOutputs() in your protocol.
+    
+    """
+    _possibleOutputs = None
+
     def __init__(self, **kwargs):
         Step.__init__(self, **kwargs)
         self._steps = []  # List of steps that will be executed
@@ -341,22 +366,7 @@ class Protocol(Step):
         self._definition = Form(self)
         self._defineParams(self._definition)
         self._createVarsFromDefinition(**kwargs)
-        self.__stdOut = None
-        self.__stdErr = None
-        self.__fOut = None
-        self.__fErr = None
-
-        class BasicLog:
-            def warning(self, message, redirectStandard=True):
-                print("WARNING", message)
-
-            def info(self, message, redirectStandard=True):
-                print("INFO", message)
-
-            def error(self, message, redirectStandard=True):
-                print("ERROR", message)
-
-        self._log = BasicLog()
+        self._log = logger
         self._buffer = ''  # text buffer for reading log files
         # Project to which the protocol belongs
         self.__project = kwargs.get('project', None)
@@ -454,6 +464,12 @@ class Protocol(Step):
         self._useOutputList.set(True)
         self._insertChild("_useOutputList", self._useOutputList)
 
+    def _closeOutputSet(self):
+        """Close all output set"""
+        for outputName, output in self.iterOutputAttributes():
+            if isinstance(output, Set) and output.isStreamOpen():
+                self.__tryUpdateOutputSet(outputName, output, state=Set.STREAM_CLOSED)
+
     def _updateOutputSet(self, outputName, outputSet,
                          state=Set.STREAM_OPEN):
         """ Use this function when updating an Stream output set.
@@ -715,12 +731,12 @@ class Protocol(Step):
 
         return protocolDict
 
-    def hasLinkedInputs(self):
-        """ Return if True if some of the input pointers are referring to
-        an output that is not ready yet.
+    def getInputStatus(self):
+        """ Returns if any input pointer is not ready yet and if there is
+         any pointer to an open set
         """
-        linkedPointers = []
-        emptyPointers = []
+        emptyPointers = False
+        openSetPointer = False
 
         for paramName, attr in self.iterInputPointers():
 
@@ -740,23 +756,39 @@ class Protocol(Step):
 
             obj = attr.get()
             if condition and obj is None and not param.allowsNull:
-                if attr.hasValue():
-                    linkedPointers.append(paramName)
-                else:
-                    emptyPointers.append(paramName)
+                if not attr.hasValue():
+                   emptyPointers = True
 
-        return linkedPointers and not emptyPointers
+            if not self.worksInStreaming() and isinstance(obj, Set) and obj.isStreamOpen():
+                openSetPointer = True
 
-    def iterOutputAttributes(self, outputClass=None):
+        return emptyPointers, openSetPointer
+
+    def iterOutputAttributes(self, outputClass=None, includePossible=False):
         """ Iterate over the outputs produced by this protocol. """
 
         iterator = self._iterOutputsNew if self._useOutputList else self._iterOutputsOld
 
-        # Iterate
+        hasOutput=False
+
+        # Iterate through actual outputs
         for key, attr in iterator():
             if outputClass is None or isinstance(attr, outputClass):
+                hasOutput = True
                 yield key, attr
 
+        # NOTE: This will only happen in case there is no actual output.
+        # There is no need to avoid duplication of actual output and possible output.
+        if includePossible and not hasOutput and self.getPossibleOutputs() is not None:
+            for possibleOutput in self.getPossibleOutputs():
+                if isinstance(possibleOutput, str):
+                    yield possibleOutput, self._possibleOutputs[possibleOutput]
+                else:
+                    yield possibleOutput.name, possibleOutput.value
+
+    def getPossibleOutputs(self):
+        return self._possibleOutputs
+
     def _iterOutputsNew(self):
         """ This methods iterates through a list where outputs have been
         annotated"""
@@ -883,12 +915,13 @@ class Protocol(Step):
         If not objects are passed, the whole protocol is stored.
         """
         if self.mapper is not None:
-            if len(objs) == 0:
-                self.mapper.store(self)
-            else:
-                for obj in objs:
-                    self.mapper.store(obj)
-            self.mapper.commit()
+            with self._lock:
+                if len(objs) == 0:
+                    self.mapper.store(self)
+                else:
+                    for obj in objs:
+                        self.mapper.store(obj)
+                self.mapper.commit()
 
     def _insertChild(self, key, child):
         """ Insert a new child not stored previously.
@@ -944,15 +977,24 @@ class Protocol(Step):
         """ Do not reset the init time in RESUME_MODE"""
         previousStart = self.initTime.get()
         super().setRunning()
-        if self.getRunMode() == MODE_RESUME:
+        if self.getRunMode() == MODE_RESUME and previousStart is not None:
             self.initTime.set(previousStart)
         else:
             self._cpuTime.set(0)
 
     def setAborted(self):
-        """ Abort the protocol and finalize the steps"""
-        super().setAborted()
-        self._updateSteps(lambda step: step.setAborted(), where="status='%s'" % STATUS_RUNNING)
+        """ Abort the protocol, finalize the steps and close all open sets"""
+        try:
+            super().setAborted()
+            self._updateSteps(lambda step: step.setAborted(), where="status='%s'" % STATUS_RUNNING)
+            self._closeOutputSet()
+        except Exception as e:
+            print("An error occurred aborting the protocol (%s)" % e)
+
+    def setFailed(self, msg):
+        """ Set the run failed and close all open  sets. """
+        super().setFailed(msg)
+        self._closeOutputSet()
 
     def _updateSteps(self, updater, where="1"):
         """Set the status of all steps
@@ -1164,7 +1206,12 @@ class Protocol(Step):
         has started running.
         """
         self.info(pwutils.magentaStr("STARTED") + ": %s, step %d, time %s" %
-                  (step.funcName.get(), step._index, step.initTime.datetime()))
+                  (step.funcName.get(), step._index, step.initTime.datetime()),
+                  extra=getExtraLogInfo("PROTOCOL", STATUS.START,
+                                        project_name=self.getProject().getName(),
+                                        prot_id=self.getObjId(),
+                                        prot_name=self.getClassName(),
+                                        step_id=step._index))
         self.__updateStep(step)
 
     def _stepFinished(self, step):
@@ -1188,7 +1235,12 @@ class Protocol(Step):
         self._store(self._stepsDone,  self._cpuTime)
 
         self.info(pwutils.magentaStr(step.getStatus().upper()) + ": %s, step %d, time %s"
-                  % (step.funcName.get(), step._index, step.endTime.datetime()))
+                  % (step.funcName.get(), step._index, step.endTime.datetime()),
+                  extra=getExtraLogInfo("PROTOCOL",STATUS.STOP,
+                                        project_name=self.getProject().getName(),
+                                        prot_id=self.getObjId(),
+                                        prot_name=self.getClassName(),
+                                        step_id=step._index))
         if step.isFailed() and self.stepsExecutionMode == STEPS_PARALLEL:
             # In parallel mode the executor will exit to close
             # all working threads, so we need to close
@@ -1391,29 +1443,40 @@ class Protocol(Step):
         """ Before calling this method, the working dir for the protocol
         to run should exists.
         """
-        self.__initLogs()
-
-        self.info(pwutils.greenStr('RUNNING PROTOCOL -----------------'))
-
-        # Store the full machine name where the protocol is running
-        # and also its PID
-        self.setPid(os.getpid())
-        self.setHostFullName(pwutils.getHostFullName())
-
-        self.info('Hostname: %s' % self.getHostFullName())
-        self.info('PID: %s' % self.getPid())
-        self.info('pyworkflow: %s' % pw.__version__)
-        self.info('plugin: %s' % self.getClassPackageName())
-        if hasattr(self.getClassPackage(), "__version__"):
-            self.info('plugin v: %s' % self.getClassPackage().__version__)
-        self.info('currentDir: %s' % os.getcwd())
-        self.info('workingDir: %s' % self.workingDir)
-        self.info('runMode: %s' % MODE_CHOICES[self.runMode.get()])
         try:
-            self.info('          MPI: %d' % self.numberOfMpi)
-            self.info('      threads: %d' % self.numberOfThreads)
+            LoggingConfigurator.setUpProtocolRunLogging(self.getLogPaths()[0], self.getLogPaths()[1] )
+
+            self.info(pwutils.greenStr('RUNNING PROTOCOL -----------------'))
+            self.info("Protocol starts", extra=getExtraLogInfo("PROTOCOL", STATUS.START,
+                                                               project_name=self.getProject().getName(),
+                                                               prot_id=self.getObjId(),
+                                                               prot_name=self.getClassName()))
+            # Store the full machine name where the protocol is running
+            # and also its PID
+            self.setPid(os.getpid())
+            self.setHostFullName(pwutils.getHostFullName())
+
+            self.info('Hostname: %s' % self.getHostFullName())
+            self.info('PID: %s' % self.getPid())
+            self.info('pyworkflow: %s' % pw.__version__)
+            self.info('plugin: %s' % self.getClassPackageName())
+            if hasattr(self.getClassPackage(), "__version__"):
+                self.info('plugin v: %s' % self.getClassPackage().__version__)
+            self.info('currentDir: %s' % os.getcwd())
+            self.info('workingDir: %s' % self.workingDir)
+            self.info('runMode: %s' % MODE_CHOICES[self.runMode.get()])
+            try:
+                self.info('          MPI: %d' % self.numberOfMpi)
+                self.info('      threads: %d' % self.numberOfThreads)
+            except Exception as e:
+                self.info('  * Cannot get information about MPI/threads (%s)' % e)
+        # Something went wrong ans at this point status is launched. We mark it as failed.
         except Exception as e:
-            self.info('  * Cannot get information about MPI/threads (%s)' % e)
+            print(e)
+            self.setFailed(str(e))
+            self._store(self.status, self.getError())
+            self._endRun()
+            return
 
         Step.run(self)
         if self.isFailed():
@@ -1435,37 +1498,16 @@ class Protocol(Step):
             self.cleanTmp()
 
         self.info(pwutils.greenStr('------------------- PROTOCOL ' +
-                                   self.getStatusMessage().upper()))
-        self.__closeLogs()
+                                   self.getStatusMessage().upper()),
+                  extra=getExtraLogInfo("PROTOCOL",STATUS.STOP,
+                                        project_name=self.getProject().getName(),
+                                        prot_id=self.getObjId(),
+                                        prot_name=self.getClassName()))
 
-    def __initLogs(self):
-        """ Open the log file overwriting its content if the protocol is going
-        to be execute from zero.
-        Otherwise append the new content to the old one.
-        Also open logs files and redirect the systems streams.
-        """
-        self._log = ScipionLogger(self.getLogPaths()[2])
-
-        if self.runMode.get() == MODE_RESTART:
-            mode = 'w+'
-        else:
-            mode = 'a'
-        # Backup the the system streams
-        self.__stdErr = sys.stderr
-        self.__stdOut = sys.stdout
-        self.__openLogsFiles(mode)
-        # Redirect the system streams to the protocol files
-        sys.stdout = self.__fOut
-        if pwutils.envVarOn('SCIPION_SEPARATE_STDERR'):
-            sys.stderr = self.__fErr
-        else:
-            sys.stderr = self.__fOut  # send stderr to wherever stdout appears
-            # TODO: maybe do not show separate "run.stdout" and "run.stderr"
-            # in the "Output Log" section if we put them together.
 
     def getLogPaths(self):
         return list(map(self._getLogsPath,
-                        ['run.stdout', 'run.stderr', 'run.log', SCHEDULE_LOG]))
+                        ['run.stdout', 'run.stderr', SCHEDULE_LOG]))
 
     def getScheduleLog(self):
         return self._getLogsPath(SCHEDULE_LOG)
@@ -1478,20 +1520,6 @@ class Protocol(Step):
         """ Return the steps.sqlite file under logs directory. """
         return self._getLogsPath('steps.sqlite')
 
-    def __openLogsFiles(self, mode):
-        self.__fOut = open(self.getLogPaths()[0], mode)
-        self.__fErr = open(self.getLogPaths()[1], mode)
-
-    def __closeLogsFiles(self):
-        self.__fOut.close()
-        self.__fErr.close()
-
-    def __closeLogs(self):
-        self._log.close()
-        # Restore system streams
-        sys.stderr = self.__stdErr
-        sys.stdout = self.__stdOut
-        self.__closeLogsFiles()
 
     def _addChunk(self, txt, fmt=None):
         """
@@ -1530,15 +1558,18 @@ class Protocol(Step):
                 outputs.append('File "%s" does not exist' % fname)
         return outputs
 
-    def getLogsLastLines(self, lastLines=None):
+    def getLogsLastLines(self, lastLines=None, logFile=0):
         """
-        Get the log last(lastLines) lines
+        Get the last(lastLines) lines of a log file.
+
+        :param lastLines, if None, will try 'PROT_LOGS_LAST_LINES' env variable, otherwise 20
+        :param logFile: Log file to take the lines from, default = 0 (std.out). 1 for stdErr.
         """
         if not lastLines:
             lastLines = int(os.environ.get('PROT_LOGS_LAST_LINES', 20))
 
         # Get stdout
-        stdoutFn =self.getLogPaths()[0]
+        stdoutFn =self.getLogPaths()[logFile]
 
         if not os.path.exists(stdoutFn):
             return []
@@ -1558,17 +1589,16 @@ class Protocol(Step):
             return output
 
     def warning(self, message, redirectStandard=True):
-        self._log.warning(message, redirectStandard)
+        self._log.warning(message)
 
-    def info(self, message, redirectStandard=True):
-        self._log.info(message, redirectStandard)
+    def info(self, message, extra=None):
+        self._log.info(message, extra= extra)
 
     def error(self, message, redirectStandard=True):
-        self._log.error(message, redirectStandard)
+        self._log.error(message)
 
     def debug(self, message):
-        if pw.Config.debugOn():
-            self.info(message)
+        self._log.debug(message)
 
     def getWorkingDir(self):
         return self.workingDir.get()
@@ -1964,20 +1994,28 @@ class Protocol(Step):
         """ Return a summary message to provide some information to users. """
         try:
             baseSummary = self._summary() or ['No summary information.']
+
+            if isinstance(baseSummary, str):
+                baseSummary = [baseSummary]
+
+            if not isinstance(baseSummary, list):
+                raise Exception("Developers error: _summary() is not returning "
+                                "a list")
+
+            comments = self.getObjComment()
+            if comments:
+                baseSummary += ['', '*COMMENTS:* ', comments]
+
+            if self.getError().hasValue():
+                baseSummary += ['', '*ERROR:*', self.getError().get()]
+
+            if self.summaryWarnings:
+                baseSummary += ['', '*WARNINGS:*']
+                baseSummary += self.summaryWarnings
+
         except Exception as ex:
             baseSummary = [str(ex)]
 
-        comments = self.getObjComment()
-        if comments:
-            baseSummary += ['', '*COMMENTS:* ', comments]
-
-        if self.getError().hasValue():
-            baseSummary += ['', '*ERROR:*', self.getError().get()]
-
-        if self.summaryWarnings:
-            baseSummary += ['', '*WARNINGS:*']
-            baseSummary += self.summaryWarnings
-
         return baseSummary
 
     def getFileTag(self, fn):
@@ -2235,6 +2273,8 @@ def runProtocolMain(projectPath, protDbPath, protId):
     # Enter to the project directory and load protocol from db
     protocol = getProtocolFromDb(projectPath, protDbPath, protId, chdir=True)
 
+    setDefaultLoggingContext(protId, protocol.getProject().getShortName())
+
     hostConfig = protocol.getHostConfig()
 
     # Create the steps executor
